@@ -32,3 +32,6 @@ from python_json_log_formatter.python_json_log_formatter import (
     PythonLogger as PythonLogger,
 )
 from python_json_log_formatter._version import __version__ as __version__
+from python_json_log_formatter.context_filter import (
+    MESSAGE_KEY_CONST as MESSAGE_KEY_CONST,
+)
